@@ -474,16 +474,21 @@ void Model::_finalizeSelect( Parser* parser, const QMap<CommandHandle, Task>::co
         return;
     }
 
+    qDebug() << "Checking sync state";
     if ( syncState.isUsableForSyncing() && oldState.isUsableForSyncing() && syncState.uidValidity() == oldState.uidValidity() ) {
+        qDebug() << "Nice resync possible";
         // Perform a nice re-sync
 
         if ( syncState.uidNext() == oldState.uidNext() ) {
+            qDebug() << "No new messages";
             // No new messages
 
             if ( syncState.exists() == oldState.exists() ) {
+                qDebug() << "No deletions";
                 // No deletions, either, so we resync only flag changes
 
                 if ( syncState.exists() ) {
+                    qDebug() << "Double checking messages";
                     // Verify that we indeed have all UIDs and not need them anymore
                     bool uidsOk = true;
                     for ( int i = 0; i < list->_children.size(); ++i ) {
@@ -530,6 +535,7 @@ void Model::_finalizeSelect( Parser* parser, const QMap<CommandHandle, Task>::co
                 saveUidMap( list );
 
             } else {
+                qDebug() << "Some deletions";
                 // Some messages got deleted, but there have been no additions
 
                 CommandHandle cmd = parser->fetch( Sequence( 1, syncState.exists() ),
@@ -549,10 +555,12 @@ void Model::_finalizeSelect( Parser* parser, const QMap<CommandHandle, Task>::co
             }
 
         } else {
+            qDebug() << "Some new messages";
             // Some new messages were delivered since we checked the last time.
             // There's no guarantee they are still present, though.
 
             if ( syncState.uidNext() - oldState.uidNext() == syncState.exists() - oldState.exists() ) {
+                qDebug() << "Only new messages";
                 // Only some new arrivals, no deletions
 
                 for ( uint i = 0; i < syncState.uidNext() - oldState.uidNext(); ++i ) {
@@ -574,6 +582,7 @@ void Model::_finalizeSelect( Parser* parser, const QMap<CommandHandle, Task>::co
                 cache()->clearUidMapping( mailbox->mailbox() );
 
             } else {
+                qDebug() << "Some new some deleted messages";
                 // Generic case; we don't know anything about which messages were deleted and which added
                 // FIXME: might be possible to optimize here...
 
@@ -594,6 +603,7 @@ void Model::_finalizeSelect( Parser* parser, const QMap<CommandHandle, Task>::co
             }
         }
     } else {
+        qDebug() << "Slooooooooooooooow sync";
         // Forget everything, do a dumb sync
         cache()->clearAllMessages( mailbox->mailbox() );
         _fullMboxSync( mailbox, list, parser, syncState );
