@@ -162,7 +162,7 @@ QVariant MsgListModel::data( const QModelIndex& proxyIndex, int role ) const
     if ( ! msgList )
         return QVariant();
 
-    if ( ! proxyIndex.isValid() || proxyIndex.model() != this )
+    if ( ! proxyIndex.isValid() )
         return QVariant();
 
     TreeItemMessage* message = dynamic_cast<TreeItemMessage*>( Model::realTreeItem( proxyIndex ) );
