@@ -34,6 +34,23 @@
 
 namespace Gui {
 
+    
+class ElidedLabel : public QLabel
+{
+    public:
+        ElidedLabel(QString label, QWidget* parent=0) : QLabel(label, parent), label(label) {};
+        ElidedLabel(QWidget* parent=0) : QLabel(parent), label() {};
+        virtual void setText(const QString& str) { label = str; };
+        
+    protected:
+        QString label;
+        
+        virtual void resizeEvent(QResizeEvent* e) {
+            QLabel::resizeEvent(e);
+            setText(fontMetrics().elidedText(label, Qt::ElideRight, e->size().width()));
+        };
+};
+    
 MsgListView::MsgListView( QWidget* parent ): QTreeView(parent)
 {
     // Hide the header!
@@ -46,6 +63,59 @@ MsgListView::MsgListView( QWidget* parent ): QTreeView(parent)
     setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     connect( header(), SIGNAL(geometriesChanged()), this, SLOT(slotFixSize()) );
+    
+    // Setup widgets used to paint rows
+    row = new QPushButton(this);
+    row->setHidden(true);
+    
+    QVBoxLayout* vlayout = new QVBoxLayout(row);
+    vlayout->setContentsMargins(5,5,5,5);
+    vlayout->setSpacing(0);
+    
+    // Create top compressor
+    {
+        QSpacerItem* compressor = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
+        vlayout->addItem(compressor);
+    }
+    
+    // Create HEADER row
+    {
+        QWidget* header = new QWidget();
+        header->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
+        QHBoxLayout* hlayout = new QHBoxLayout(header);
+        hlayout->setContentsMargins(0,0,0,0);
+        
+        // Create FROM label
+        {
+            from = new QLabel();
+            from->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
+            hlayout->addWidget(from);
+        }
+        
+        // Create DATE label
+        {
+            date = new QLabel();
+            date->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
+            date->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+            hlayout->addWidget(date);
+        }
+        
+        vlayout->addWidget(header);
+    }
+    
+    // Create SUBJECT row
+    {
+        subject = new ElidedLabel();
+        subject->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
+        vlayout->addWidget(subject);
+    }
+    
+    
+    // Create bottom compressor
+    {
+        QSpacerItem* compressor = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
+        vlayout->addItem(compressor);
+    }
 }
 
 int MsgListView::sizeHintForColumn( int column ) const
@@ -60,17 +130,17 @@ int MsgListView::sizeHintForColumn( int column ) const
             return fontMetrics().size( Qt::TextSingleLine, QLatin1String("Blesmrt Trojita") ).width();
         case Imap::Mailbox::MsgListModel::DATE:
             // Note: make sure this is what the model's doing
-			{
-				// A date that should be close to the "longest formatted date"
-				// Assuming a sane font :)
-				QDateTime dt(QDate(2099, 10, 30), QTime(20, 59, 999));
-				QString timeString = dt.time().toString( Qt::SystemLocaleShortDate );
-				QString dayString = dt.date().toString( Qt::DefaultLocaleShortDate );
-				qDebug() << "datetime hint" << timeString << dayString;
-				int timeWidth = fontMetrics().size( Qt::TextSingleLine, timeString).width();
-				int dayWidth = fontMetrics().size( Qt::TextSingleLine, dayString).width();
-				return (timeWidth < dayWidth?dayWidth:timeWidth)*1.2;
-			}
+            {
+                // A date that should be close to the "longest formatted date"
+                // Assuming a sane font :)
+                QDateTime dt(QDate(2099, 10, 30), QTime(20, 59, 999));
+                QString timeString = dt.time().toString( Qt::SystemLocaleShortDate );
+                QString dayString = dt.date().toString( Qt::DefaultLocaleShortDate );
+                qDebug() << "datetime hint" << timeString << dayString;
+                int timeWidth = fontMetrics().size( Qt::TextSingleLine, timeString).width();
+                int dayWidth = fontMetrics().size( Qt::TextSingleLine, dayString).width();
+                return (timeWidth < dayWidth?dayWidth:timeWidth)*1.2;
+            }
         case Imap::Mailbox::MsgListModel::SIZE:
             return fontMetrics().size( Qt::TextSingleLine, QLatin1String("888.1 kB") ).width();
         default:
@@ -90,20 +160,6 @@ void MsgListView::slotFixSize()
     header()->setResizeMode( Imap::Mailbox::MsgListModel::SEEN, QHeaderView::Fixed );
 }
 
-class ElidedLabel : public QLabel
-{
-    public:
-        ElidedLabel(QString label, QWidget* parent=0) : QLabel(label, parent), label(label) {};
-
-    protected:
-        QString label;
-        
-        virtual void resizeEvent(QResizeEvent* e) {
-            QLabel::resizeEvent(e);
-            setText(fontMetrics().elidedText(label, Qt::ElideRight, e->size().width()));
-        };
-};
-
 void MsgListView::drawRow ( QPainter * painter, const QStyleOptionViewItem  & option, const QModelIndex  & index ) const
 {
     const QAbstractItemModel* model = index.model();
@@ -111,66 +167,28 @@ void MsgListView::drawRow ( QPainter * painter, const QStyleOptionViewItem  & op
     QVariant qdate = model->index(index.row(), Imap::Mailbox::MsgListModel::DATE).data();
     QVariant qfrom = model->index(index.row(), Imap::Mailbox::MsgListModel::FROM).data();
 
-    QPushButton* row = new QPushButton();
+    // Setup Row
     row->setFixedSize(option.rect.size());
-
-    QVBoxLayout* vlayout = new QVBoxLayout(row);
-    vlayout->setContentsMargins(5,5,5,5);
-    vlayout->setSpacing(0);
-
-    // Create top compressor
-    {
-        QSpacerItem* compressor = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
-        vlayout->addItem(compressor);
-    }
+    QFont font = option.font;
+    font.setPixelSize(15);
     
-    // Create HEADER row
-    {
-        QWidget* header = new QWidget();
-        header->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
-        QHBoxLayout* hlayout = new QHBoxLayout(header);
-        hlayout->setContentsMargins(0,0,0,0);
-        QFont font = option.font;
-        font.setPixelSize(15);
-        
-        // Create FROM label
-        {
-            QLabel* from = new QLabel(qfrom.toString());
-            from->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
-            from->setFont(font);
-            hlayout->addWidget(from);
-        }
-        
-        // Create DATE label
-        {
-            QLabel* date = new QLabel(qdate.toString());
-            date->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
-            date->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-            date->setFont(font);
-            hlayout->addWidget(date);
-        }
-        
-        vlayout->addWidget(header);
-    }
+    // Set FROM
+    from->setText(qfrom.toString());
+    from->setFont(font);
+    
+    // Set DATE
+    date->setText(qdate.toString());
+    date->setFont(font);
+    
+    // Set SUBJECT
+    font = index.data(Qt::FontRole).value<QFont>(); 
+    font.setPixelSize(20);
+    subject->setText(qsubject.toString());
+    subject->setFont(font);
+    
+    // Finalize
+    row->updateGeometry();
     
-    // Create SUBJECT row
-    {
-        QFont font = index.data(Qt::FontRole).value<QFont>(); 
-        font.setPixelSize(20);
-        
-        QLabel* subject = new ElidedLabel(qsubject.toString());
-        subject->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
-        subject->setFont(font);
-        vlayout->addWidget(subject);
-    }
-
-
-    // Create bottom compressor
-    {
-        QSpacerItem* compressor = new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding);
-        vlayout->addItem(compressor);
-    }
-
     // Stylize the row :)
     const char* normalStyle =
         "QPushButton {"
@@ -199,7 +217,6 @@ void MsgListView::drawRow ( QPainter * painter, const QStyleOptionViewItem  & op
     rect.moveTop(rect.top()+viewport()->y());
     rect.moveLeft(rect.left()+viewport()->x());
     row->render(painter, rect.topLeft());
-    delete row;
 }
 
 
