@@ -22,6 +22,8 @@
 #define MSGLISTVIEW_H
 
 #include <QTreeView>
+#include <QPushButton>
+#include <QLabel>
 
 namespace Gui {
 
@@ -36,6 +38,11 @@ public:
 protected:
     virtual int sizeHintForColumn( int column ) const;
     virtual void drawRow ( QPainter * painter, const QStyleOptionViewItem  & option, const QModelIndex  & index ) const;
+private:
+    QPushButton* row;
+    QLabel* from;
+    QLabel* date;
+    QLabel* subject;
 private slots:
     void slotFixSize();
 };
