@@ -94,18 +94,6 @@ void MainWindow::createActions()
     reloadAllMailboxes = new QAction( tr("Reload Everything"), this );
     // connect later
 
-    QActionGroup* netPolicyGroup = new QActionGroup( this );
-    netPolicyGroup->setExclusive( true );
-    netOffline = new QAction( QIcon( QLatin1String(":/icons/network-offline") ), tr("Offline"), netPolicyGroup );
-    netOffline->setCheckable( true );
-    // connect later
-    netExpensive = new QAction( QIcon( QLatin1String(":/icons/network-expensive") ), tr("Expensive Connection"), netPolicyGroup );
-    netExpensive->setCheckable( true );
-    // connect later
-    netOnline = new QAction( QIcon( QLatin1String(":/icons/network-online") ), tr("Free Access"), netPolicyGroup );
-    netOnline->setCheckable( true );
-    // connect later
-
     showImapLogger = new QAction( tr("Show IMAP protocol log"), this );
     showImapLogger->setCheckable( true );
     connect( showImapLogger, SIGNAL(triggered(bool)), imapLoggerDock, SLOT(setShown(bool)) );
