@@ -204,7 +204,9 @@ void ImapParserParseTest::testParseUntagged_data()
     QTest::newRow("untagged-list-mailbox-quote")
         << QByteArray("* LIST () \".\" \"some\\\"Name\"\r\n")
         << QSharedPointer<AbstractResponse>( new List( LIST, QStringList(), ".", "some\"Name" ) );
-#include "test_Imap_Parser_parse-Chinese.include"
+    QTest::newRow("untagged-list-unicode")
+        << QByteArray("* LIST () \"/\" \"~Peter/mail/&U,BTFw-/&ZeVnLIqe-\"\r\n")
+        << QSharedPointer<AbstractResponse>( new List( LIST, QStringList(), "/", QString::fromUtf8("~Peter/mail/台北/日本語") ) );
     QTest::newRow("untagged-list-inbox-atom")
         << QByteArray("* LIST () \"/\" inBox\r\n")
         << QSharedPointer<AbstractResponse>( new List( LIST, QStringList(), "/", "INBOX") );
